# Javascript Components

## What are Javascript Components?

Javascript components are the simple implementation of Javascript code that can be used to create a reusable component. These components can be used to create a reusable code that can be used in multiple places in the application. It is very easy to create a Javascript component and use it in the application. You can easily implement some of the common functionalities in the Javascript component and use it in the application. We are currently have some very basic components which we are planning to expand in the future.

## How to use Javascript Components?

